
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

/*
 * Copyright (C) 2017 Igalia S.L.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#if !defined(__WEBKIT_WEB_PROCESS_EXTENSION_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkit${WEBKITGTK_API_INFIX}/webkit-web-extension.h> can be included directly."
#endif

#ifndef WEBKIT_WEB_PROCESS_ENUM_TYPES_H
#define WEBKIT_WEB_PROCESS_ENUM_TYPES_H

#include <glib-object.h>
#include <webkit/WebKitDefines.h>

G_BEGIN_DECLS
/* Enumerations from WebKitConsoleMessage.h. */
#define WEBKIT_TYPE_CONSOLE_MESSAGE_SOURCE webkit_console_message_source_get_type ()

WEBKIT_API GType
webkit_console_message_source_get_type (void);
#define WEBKIT_TYPE_CONSOLE_MESSAGE_LEVEL webkit_console_message_level_get_type ()

WEBKIT_API GType
webkit_console_message_level_get_type (void);
/* Enumerations from WebKitWebPage.h. */
#define WEBKIT_TYPE_FORM_SUBMISSION_STEP webkit_form_submission_step_get_type ()

WEBKIT_API GType
webkit_form_submission_step_get_type (void);
G_END_DECLS

#endif

/* Generated data ends here */

